@@ -9,7 +9,7 @@ from typing import Any, Optional
 import attrs
 import packaging.version
 
-from acconeer.exptool.a121._core.utils import parse_rss_version
+from acconeer.exptool.a121._core import utils
 
 
 @attrs.frozen(kw_only=True)
@@ -33,6 +33,16 @@ class SensorInfo:
     def from_json(cls, json_str: str) -> SensorInfo:
         return cls.from_dict(json.loads(json_str))
 
+    def _pretty_str_lines(self, index: Optional[int] = None) -> list[str]:
+        index_str = "" if index is None else f" @ slot {index}"
+        return [
+            f"{type(self).__name__}{index_str}:",
+            *utils.pretty_dict_line_strs(self.to_dict()),
+        ]
+
+    def __str__(self) -> str:
+        return "\n".join(self._pretty_str_lines())
+
 
 @attrs.frozen(kw_only=True)
 class ServerInfo:
@@ -45,7 +55,7 @@ class ServerInfo:
 
     @property
     def parsed_rss_version(self) -> packaging.version.Version:
-        return parse_rss_version(self.rss_version)
+        return utils.parse_rss_version(self.rss_version)
 
     def to_dict(self) -> dict[str, Any]:
         return attrs.asdict(self)
@@ -65,3 +75,22 @@ class ServerInfo:
     @classmethod
     def from_json(cls, json_str: str) -> ServerInfo:
         return cls.from_dict(json.loads(json_str))
+
+    def __str__(self) -> str:
+        d = self.to_dict()
+        del d["sensor_infos"]
+
+        sensor_infos_strs = [
+            line
+            for i, sensor_info in self.sensor_infos.items()
+            for line in utils.indent_strs(sensor_info._pretty_str_lines(index=i), 2)
+        ]
+
+        return "\n".join(
+            [
+                f"{type(self).__name__}:",
+                *utils.pretty_dict_line_strs(d),
+                "  sensor_infos:",
+                *sensor_infos_strs,
+            ]
+        )
