@@ -9,6 +9,7 @@ import time
 from typing import Any, Callable, Iterator, Optional, Tuple, Type, Union
 
 import attrs
+from serial.serialutil import SerialException
 
 from acconeer.exptool.a121._core.entities import (
     ClientInfo,
@@ -56,7 +57,7 @@ class AgnosticClient(AgnosticClientFriends):
     _session_is_started: bool
     _metadata: Optional[list[dict[int, Metadata]]]
     _sensor_calibrations: Optional[dict[int, SensorCalibration]]
-    _calibration_provided: dict[int, bool]
+    _calibrations_provided: dict[int, bool]
     _sensor_infos: dict[int, SensorInfo]
     _system_info: Optional[SystemInfoDict]
     _result_queue: list[list[dict[int, Result]]]
@@ -74,7 +75,7 @@ class AgnosticClient(AgnosticClientFriends):
         self._session_is_started = False
         self._metadata = None
         self._sensor_calibrations = None
-        self._calibration_provided = {}
+        self._calibrations_provided = {}
         self._sensor_infos = {}
         self._system_info = None
         self._result_queue = []
@@ -168,7 +169,26 @@ class AgnosticClient(AgnosticClientFriends):
         """
         self._default_link_timeout = self._link.timeout
         self._link_timeout = self._default_link_timeout
-        self._link.connect()
+
+        try:
+            self._link.connect()
+        except SerialException as exc:
+            if "Permission denied" in str(exc):
+                text = "\n".join(
+                    [
+                        str(exc),
+                        "",
+                        "You are probably missing permissions to access the serial port.",
+                        "",
+                        "Run the setup script to fix it:",
+                        "$ python -m acconeer.exptool.setup",
+                        "",
+                        "Reboot for the changes to take effect.",
+                    ]
+                )
+                raise ClientError(text) from exc
+            else:
+                raise
 
         self._message_stream = self._get_message_stream()
 
@@ -212,12 +232,12 @@ class AgnosticClient(AgnosticClientFriends):
 
         config.validate()
 
-        self._calibration_provided = {}
+        self._calibrations_provided = {}
         for _, sensor_id, _ in iterate_extended_structure(config.groups):
             if calibrations:
-                self._calibration_provided[sensor_id] = sensor_id in calibrations
+                self._calibrations_provided[sensor_id] = sensor_id in calibrations
             else:
-                self._calibration_provided[sensor_id] = False
+                self._calibrations_provided[sensor_id] = False
 
         self._link.send(self._protocol.setup_command(config, calibrations))
 
@@ -258,7 +278,7 @@ class AgnosticClient(AgnosticClientFriends):
             raise ClientError("Session is already started.")
 
         if recorder is not None:
-            calibrations_provided = self.calibrations_provided
+            calibrations_provided: Optional[dict[int, bool]] = self.calibrations_provided
             try:
                 calibrations = self.calibrations
             except ClientError:
@@ -455,7 +475,7 @@ class AgnosticClient(AgnosticClientFriends):
         this attribute will return ``{1: False, 2: True}``
         """
 
-        return self._calibration_provided
+        return self._calibrations_provided
 
     @property
     def _rate_stats(self) -> _RateStats:
