@@ -4,7 +4,7 @@
 from .erroneus_message import ErroneousMessage
 from .log_message import LogMessage
 from .parse_error import ParseError
-from .result_message import ResultMessage
+from .result_message import EmptyResultMessage, ResultMessage
 from .sensor_info_response import SensorInfoResponse
 from .set_baudrate_response import SetBaudrateResponse
 from .setup_response import SetupResponse
