@@ -6,6 +6,7 @@ from __future__ import annotations
 import datetime
 import os
 from pathlib import Path
+from time import time
 from typing import Any, Optional, TypeVar
 from uuid import uuid4
 
@@ -47,28 +48,60 @@ def get_uuid() -> str:
 
 
 class H5Recorder(Recorder):
+    """Recorder writing directly to an HDF5 file
+
+    :param path_or_file:
+        If a path-like object, by default (depending on ``mode`` below) an HDF5 file is created at
+        that path. When stopping, the file is closed.
+
+        If an ``h5py.File``, that file is used as-is. In this case, the file is not closed when
+        stopping.
+    :param mode:
+        The file mode to use if a path-like object was given for ``path_or_file``. Default value is
+        'x', meaning that we open for exclusive creation, failing if the file already exists.
+    :param _chunk_size:
+        If given, data will be written to file every ``_chunk_size`` samples.
+
+        If not given, data will be written at least every 512:th sample, or at least once per
+        second, whichever comes first.
+
+        Setting a small chunk size (e.g. 1) may degrade performance for high sample rates.
+
+        Internal parameter, subject to change.
+    """
+
+    _AUTO_CHUNK_MAX_SIZE = 512
+    _AUTO_CHUNK_MAX_TIME = 1.0
+
     path: Optional[os.PathLike]
+    """The file path, if a path-like object was given for ``path_or_file``."""
     file: h5py.File
+    """The ``h5py.File``."""
     owns_file: bool
+    """Whether :class:`H5Recorder` opened and owns the file, i.e., if a path-like object was given
+    for ``path_or_file``. If it does, the file is closed when stopping.
+    """
     _num_frames: int
-    chunk_size: int
-    chunk_buffer: list[list[dict[int, Result]]]
+    _chunk_size: Optional[int]
+    _chunk_buffer: list[list[dict[int, Result]]]
+    _last_write_time: float
 
     def __init__(
         self,
         path_or_file: PathOrH5File,
         mode: str = "x",
         *,
-        _chunk_size: int = 512,
+        _chunk_size: Optional[int] = None,
         _lib_version: Optional[str] = None,
         _timestamp: Optional[str] = None,
         _uuid: Optional[str] = None,
     ) -> None:
         self.file, self.owns_file = h5_file_factory(path_or_file, h5_file_mode=mode)
         self.path = Path(self.file.filename) if self.owns_file else None
-        self.chunk_size = _chunk_size
-        self.chunk_buffer = []
+        self._chunk_size = _chunk_size
+        self._chunk_buffer = []
         self._num_frames = 0
+        self._last_write_time = 0.0
 
         if _lib_version is None:
             _lib_version = importlib_metadata.version("acconeer-exptool")
@@ -162,27 +195,26 @@ class H5Recorder(Recorder):
             calibrations_group = session_group.create_group("calibrations")
             for sensor_id, calibration in calibrations.items():
                 sensor_calibration_group = calibrations_group.create_group(f"sensor_{sensor_id}")
-                sensor_calibration_group.create_dataset(
-                    "temperature", data=calibration.temperature, track_times=False
-                )
-                sensor_calibration_group.create_dataset(
-                    "data",
-                    data=calibration.data,
-                    dtype=_H5PY_STR_DTYPE,
-                    track_times=False,
-                )
+
+                calibration.to_h5(sensor_calibration_group)
+
                 sensor_calibration_group.create_dataset(
                     "provided", data=calibrations_provided[sensor_id], track_times=False
                 )
 
+        self._last_write_time = time()
+
     def _write_chunk_buffer_to_file(self, start_idx: int) -> int:
         """Saves the contents of ``self.chunk_buffer`` to file.
 
         :returns: the number of extended results saved.
         """
 
+        if len(self._chunk_buffer) == 0:
+            return 0
+
         for group_idx, entry_idx, results in utils.iterate_extended_structure_as_entry_list(
-            utils.transpose_extended_structures(self.chunk_buffer)
+            utils.transpose_extended_structures(self._chunk_buffer)
         ):
             self._write_results(
                 g=self.file[f"session/group_{group_idx}/entry_{entry_idx}/result"],
@@ -190,18 +222,26 @@ class H5Recorder(Recorder):
                 results=results,
             ),
 
-        return len(self.chunk_buffer)
+        return len(self._chunk_buffer)
 
     def _sample(self, extended_result: list[dict[int, Result]]) -> None:
-        self.chunk_buffer.append(extended_result)
+        self._chunk_buffer.append(extended_result)
 
-        if len(self.chunk_buffer) == self.chunk_size:
+        if self._chunk_size is None:
+            reached_size_limit = len(self._chunk_buffer) >= self._AUTO_CHUNK_MAX_SIZE
+            reached_time_limit = (time() - self._last_write_time) >= self._AUTO_CHUNK_MAX_TIME
+            write = reached_size_limit or reached_time_limit
+        else:
+            write = len(self._chunk_buffer) == self._chunk_size
+
+        if write:
             self._num_frames += self._write_chunk_buffer_to_file(start_idx=self._num_frames)
-            self.chunk_buffer = []
+            self._chunk_buffer = []
+            self._last_write_time = time()
 
     def _stop(self) -> Any:
         self._num_frames += self._write_chunk_buffer_to_file(start_idx=self._num_frames)
-        self.chunk_buffer = []
+        self._chunk_buffer = []
 
         if self.owns_file:
             self.file.close()
@@ -279,6 +319,11 @@ class H5Recorder(Recorder):
         g["frame"][dataset_slice] = [result._frame for result in results]
 
     def require_algo_group(self, key: str) -> h5py.Group:
+        """Creates/gets the ``algo`` group with a given ``key``.
+
+        :raises: Exception if the key does not match the file content
+        """
+
         group = self.file.require_group("algo")
 
         if "key" in group:
