@@ -4,6 +4,7 @@
 from acconeer.exptool.a121.algo._plugins import processor_main
 
 from . import Processor, ProcessorConfig, get_near_sensor_config
+from ._blinkstick_updater import BlinkstickUpdater
 from ._plugin import PlotPlugin
 
 
@@ -12,4 +13,5 @@ processor_main(
     processor_config_cls=ProcessorConfig,
     plot_plugin=PlotPlugin,
     sensor_config_getter=get_near_sensor_config,
+    _blinkstick_updater_cls=BlinkstickUpdater,
 )
